#ifndef NAUTILUS_ICON_NAMES_H
#define NAUTILUS_ICON_NAMES_H

/* Icons for places */
#define NAUTILUS_ICON_COMPUTER		"computer"
#define NAUTILUS_ICON_DESKTOP		"user-desktop"
#define NAUTILUS_ICON_FILESYSTEM	"drive-harddisk"
#define NAUTILUS_ICON_FOLDER		"folder"
#define NAUTILUS_ICON_FOLDER_REMOTE	"folder-remote"
#define NAUTILUS_ICON_HOME		"user-home"
#define NAUTILUS_ICON_NETWORK		"network-workgroup"
#define NAUTILUS_ICON_NETWORK_SERVER	"network-server"
#define NAUTILUS_ICON_SEARCH		"system-search"
#define NAUTILUS_ICON_TRASH		"user-trash"
#define NAUTILUS_ICON_TRASH_FULL	"user-trash-full"
#define NAUTILUS_ICON_DELETE		"edit-delete"

#define NAUTILUS_ICON_FOLDER_DESKTOP    "user-desktop"
#define NAUTILUS_ICON_FOLDER_DOCUMENTS  "folder-documents"
#define NAUTILUS_ICON_FOLDER_DOWNLOAD   "folder-download"
#define NAUTILUS_ICON_FOLDER_MUSIC      "folder-music"
#define NAUTILUS_ICON_FOLDER_PICTURES   "folder-pictures"
#define NAUTILUS_ICON_FOLDER_PUBLIC_SHARE "folder-publicshare"
#define NAUTILUS_ICON_FOLDER_TEMPLATES  "folder-templates"
#define NAUTILUS_ICON_FOLDER_VIDEOS     "folder-videos"
#define NAUTILUS_ICON_FOLDER_SAVED_SEARCH "folder-saved-search"

/* Other icons */
#define NAUTILUS_ICON_TEMPLATE		"text-x-generic-template"

/* Icons not provided by fd.o naming spec or nautilus itself */
#define NAUTILUS_ICON_BURN		"nautilus-cd-burner"

#endif /* NAUTILUS_ICON_NAMES_H */

